#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sqlite-simple
version:              0.4.19.0
visibility:           public
id:                   sqlite-simple-0.4.19.0-KN9arrmybRQ4egGhKfLAaG
key:                  sqlite-simple-0.4.19.0-KN9arrmybRQ4egGhKfLAaG
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.,
    (c) 2011-2012 Leon P Smith,
    (c) 2012-2014 Janne Hellsten

maintainer:           Janne Hellsten <jjhellst@gmail.com>
author:               Bryan O'\''Sullivan, Leon P Smith, Janne Hellsten
stability:            stable
homepage:             http://github.com/nurpax/sqlite-simple
synopsis:             Mid-Level SQLite client library
description:
    Mid-level SQLite client library, based on postgresql-simple.

    Main documentation (with examples): <docs/Database-SQLite-Simple.html Database.SQLite.Simple>

    You can view the project page at <http://github.com/nurpax/sqlite-simple>
    for more information.

category:             Database
abi:                  03ca02679ab6eba86ace8150387ef592
exposed:              True
exposed-modules:
    Database.SQLite.Simple Database.SQLite.Simple.FromField
    Database.SQLite.Simple.FromRow Database.SQLite.Simple.Function
    Database.SQLite.Simple.Internal Database.SQLite.Simple.Ok
    Database.SQLite.Simple.QQ Database.SQLite.Simple.Time
    Database.SQLite.Simple.Time.Implementation
    Database.SQLite.Simple.ToField Database.SQLite.Simple.ToRow
    Database.SQLite.Simple.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/sqlite-simple-0.4.19.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sqlite-simple-0.4.19.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sqlite-simple-0.4.19.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sqlite-simple
hs-libraries:         HSsqlite-simple-0.4.19.0-KN9arrmybRQ4egGhKfLAaG
depends:
    Only-0.1-DItEcvi68ww8z5TVixWVcj
    attoparsec-0.14.4-GXkoXdfu9eSCi2jWr4IsoQ base-4.18.2.1
    blaze-builder-0.4.4.1-1gCRyl7Vcti9aC8OeyihWk
    blaze-textual-0.2.3.1-GM8f2nwQryqC8Mc1bXTRta bytestring-0.11.5.3
    containers-0.6.7 direct-sqlite-2.3.29-Bbi5ey9UPjg21oM0e6OWU8
    exceptions-0.10.7 template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-sqlite-simple/html/sqlite-simple.haddock

haddock-html:         /usr/share/doc/haskell-sqlite-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

